@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Massachusetts
-    Institute of Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -96,9 +96,9 @@ FLAGS is a string containing the desired labels, separated by commas."
      (string-append "Flags " flags-string)
      (let ((flags (burst-comma-list-string flags-string)))
        (lambda (m)
-	 (there-exists? (message-flags m)
-	   (lambda (flag)
-	     (flags-member? flag flags))))))))
+	 (any (lambda (flag)
+		(flags-member? flag flags))
+	      (message-flags m)))))))
 
 (define-command imail-summary-by-recipients
   "Display a summary of all messages with the given RECIPIENTS.
@@ -512,27 +512,29 @@ SUBJECT is a string of regexps separated by commas."
 	    (buffer-not-modified! buffer))))))
 
 (define (write-imail-summary-line! message index-digits mark)
-  (insert-char #\space mark)
-  (insert-string (message-flag-markers message) mark)
-  (insert-char #\space mark)
-  (insert-message-index (+ (message-index message) 1) index-digits mark)
-  (insert-string "  " mark)
-  (insert-string (message-summary-length-string message) mark)
-  (if (ref-variable imail-summary-show-date mark)
-      (begin
-	(insert-string " " mark)
-	(insert-string (message-summary-date-string message) mark)))
-  (insert-string "  " mark)
-  (let ((target-column
-	 (fix:+ (mark-column mark) (imail-summary-subject-width mark))))
-    (insert-string (message-summary-subject-string message) mark)
-    (if (fix:> (mark-column mark) target-column)
-	(delete-string (move-to-column mark target-column) mark))
-    (if (fix:< (mark-column mark) target-column)
-	(insert-chars #\space (fix:- target-column (mark-column mark)) mark)))
-  (insert-string "  " mark)
-  (insert-string (message-summary-from-string message) mark)
-  (insert-newline mark))
+  (let ((header (message-header-fields message)))
+    (insert-char #\space mark)
+    (insert-string (message-flag-markers message) mark)
+    (insert-char #\space mark)
+    (insert-message-index (+ (message-index message) 1) index-digits mark)
+    (insert-string "  " mark)
+    (insert-string (message-summary-length-string message) mark)
+    (if (ref-variable imail-summary-show-date mark)
+	(begin
+	  (insert-string " " mark)
+	  (insert-string (message-summary-date-string message) mark)))
+    (insert-string "  " mark)
+    (let ((target-column
+	   (fix:+ (mark-column mark) (imail-summary-subject-width mark))))
+      (insert-string (message-summary-subject-string message) mark)
+      (if (fix:> (mark-column mark) target-column)
+	  (delete-string (move-to-column mark target-column) mark))
+      (if (fix:< (mark-column mark) target-column)
+	  (insert-chars #\space (fix:- target-column (mark-column mark)) mark)))
+    (insert-string "  " mark)
+    (insert-string (message-summary-from-string message) mark)
+    (insert-newline mark)
+    (reference-barrier header)))
 
 (define (insert-message-index index index-digits mark)
   (insert-string-pad-left (number->string index) index-digits #\space mark))
