@@ -2,8 +2,8 @@
 
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
-    2006, 2007, 2008, 2009, 2010, 2011 Massachusetts Institute of
-    Technology
+    2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
+    2017, 2018, 2019 Massachusetts Institute of Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -38,7 +38,7 @@ USA.
 
 (define (merge-sort! v pred)
   (if (not (vector? v))
-      (error:wrong-type-argument v "vector" 'MERGE-SORT!))
+      (error:wrong-type-argument v "vector" 'merge-sort!))
   (let sort-subvector
       ((v v)
        (temp (vector-copy v))
